@@ -23,7 +23,7 @@ from sklearn.model_selection import train_test_split, GridSearchCV
 from sklearn.svm import SVC # SVC(C=1.0, ...) 与 nuSVC(nu = 0.5, ...) 的区别：前者使用C～[0，inf），后者使用nu～(0,1]，惩罚性的解释不同，优化都可以使用GridSearch方法
 from scipy.signal import savgol_filter
 
-def analyze(id, x_range = None, y_subset=None, shift = 100):
+def analyze(id, x_range = None, y_subset=None, shift = 100, cla_feature_num = 10):
     '''
     id : dataset id or a full path
     '''
@@ -50,7 +50,7 @@ def analyze(id, x_range = None, y_subset=None, shift = 100):
     X_f = filter_dataset(X, nlc = 0.002, nhc = None)  # axis = 0 for vertically; axis = 1 for horizontally
     plt.figure(figsize = (40,10))
     plt.scatter(X_names, np.mean(X_f,axis=0).tolist()) 
-    plt.title(u'Averaged Spectrum After Butterworth Filter', fontsize=30)
+    plt.title(u'Averaged Spectrum After Butterworth Filter\n若效果不佳，需要调试优化高通滤波器的截止频率', fontsize=30)
     plt.show()
 
     display(HTML('<hr/><h3>特征缩放</h3>'))
@@ -64,6 +64,7 @@ def analyze(id, x_range = None, y_subset=None, shift = 100):
 
     mm_scaler = MinMaxScaler()
     X_mm_scaled = mm_scaler.fit_transform(X)
+    print('X_mm_scaled is rescaled to [0,1]. We use X_mm_scaled in the MFDR and feature selectioin section.')
 
     display(HTML('<hr/><h2>降维</h2>'))
     # Dimension Reduction & Visualization
@@ -128,7 +129,7 @@ LDA for two categories tries to maximize distance between group means, meanwhile
 { (\mu_1 - \mu_2)^2 } \over { s_1^2 + s_2^2 }')
     print('Risk of using LDA: Possible Warning - Variables are collinear. \n\
 LDA, like regression techniques involves computing a matrix inversion, which is inaccurate if the determinant is close to 0 (i.e. two or more variables are almost a linear combination of each other). \n\
-More importantly, it makes the estimated coefficients impossible to interpret. If an increase in X1 , say, is associated with an decrease in X2 and they both increase variable Y, every change in X1 will be compensated by a change in X2 and you will underestimate the effect of X1 on Y. In LDA, you would underestimate the effect of X1 on the classification. If all you care for is the classification per se, and that after training your model on half of the data and testing it on the other half you get 85-95%% accuracy I\'d say it is fine. ')
+More importantly, it makes the estimated coefficients impossible to interpret. If an increase in X1 , say, is associated with an decrease in X2 and they both increase variable Y, every change in X1 will be compensated by a change in X2 and you will underestimate the effect of X1 on Y. In LDA, you would underestimate the effect of X1 on the classification. If all you care for is the classification per se, and that after training your model on half of the data and testing it on the other half you get 85-95% accuracy I\'d say it is fine. ')
     display(HTML('<hr/>'))
 
     pls = PLSRegression(n_components=2, scale = True)
@@ -175,8 +176,11 @@ ADVANTAGES: Deal with multi-colinearity; Interpretation by data structure')
     display(HTML('<hr/>'))
 
     if len(set(y)) == 2:
-        display(HTML('<hr/><h2>可分性度量</h2>'))
-        display(HTML(metrics.get_html(X_enet,y)))
+        if cla_feature_num is None:
+            cla_feature_num = X_enet.shape[1] # use all selected features
+
+        display(HTML('<hr/><h2>可分性度量(top-'+ str(cla_feature_num) +' selected features)</h2>'))
+        display(HTML(metrics.get_html(X_enet[:,:cla_feature_num],y)))
     
     display(HTML('<hr/><h2>分类</h2><h3>超参数优化及模型选择 （SVM）</h3>'))
     
